==> quarkus-datasource-1.3.2.Final-sources.jar: io/quarkus/datasource/runtime/DataSourceRuntimeConfig$$accessor.java <==
package io.quarkus.datasource.runtime;
public final class DataSourceRuntimeConfig$$accessor {
    private DataSourceRuntimeConfig$$accessor() {}
    @SuppressWarnings("unchecked")
    public static Object get_username(Object __instance) {
        return ((DataSourceRuntimeConfig)__instance).username;
    }
    @SuppressWarnings("unchecked")
    public static void set_username(Object __instance, Object username) {
        ((DataSourceRuntimeConfig)__instance).username = (java.util.Optional<String>)username;
    }
    @SuppressWarnings("unchecked")
    public static Object get_password(Object __instance) {
        return ((DataSourceRuntimeConfig)__instance).password;
    }
    @SuppressWarnings("unchecked")
    public static void set_password(Object __instance, Object password) {
        ((DataSourceRuntimeConfig)__instance).password = (java.util.Optional<String>)password;
    }
    @SuppressWarnings("unchecked")
    public static Object get_credentialsProvider(Object __instance) {
        return ((DataSourceRuntimeConfig)__instance).credentialsProvider;
    }
    @SuppressWarnings("unchecked")
    public static void set_credentialsProvider(Object __instance, Object credentialsProvider) {
        ((DataSourceRuntimeConfig)__instance).credentialsProvider = (java.util.Optional<String>)credentialsProvider;
    }
    @SuppressWarnings("unchecked")
    public static Object get_credentialsProviderType(Object __instance) {
        return ((DataSourceRuntimeConfig)__instance).credentialsProviderType;
    }
    @SuppressWarnings("unchecked")
    public static void set_credentialsProviderType(Object __instance, Object credentialsProviderType) {
        ((DataSourceRuntimeConfig)__instance).credentialsProviderType = (java.util.Optional<String>)credentialsProviderType;
    }
    public static Object construct() {
        return new DataSourceRuntimeConfig();
    }
}

==> quarkus-datasource-1.5.0.Final-sources.jar: io/quarkus/datasource/runtime/DataSourceRuntimeConfig$$accessor.java <==
package io.quarkus.datasource.runtime;
public final class DataSourceRuntimeConfig$$accessor {
    private DataSourceRuntimeConfig$$accessor() {}
    @SuppressWarnings("unchecked")
    public static Object get_username(Object __instance) {
        return ((DataSourceRuntimeConfig)__instance).username;
    }
    @SuppressWarnings("unchecked")
    public static void set_username(Object __instance, Object username) {
        ((DataSourceRuntimeConfig)__instance).username = (java.util.Optional<String>)username;
    }
    @SuppressWarnings("unchecked")
    public static Object get_password(Object __instance) {
        return ((DataSourceRuntimeConfig)__instance).password;
    }
    @SuppressWarnings("unchecked")
    public static void set_password(Object __instance, Object password) {
        ((DataSourceRuntimeConfig)__instance).password = (java.util.Optional<String>)password;
    }
    @SuppressWarnings("unchecked")
    public static Object get_credentialsProvider(Object __instance) {
        return ((DataSourceRuntimeConfig)__instance).credentialsProvider;
    }
    @SuppressWarnings("unchecked")
    public static void set_credentialsProvider(Object __instance, Object credentialsProvider) {
        ((DataSourceRuntimeConfig)__instance).credentialsProvider = (java.util.Optional<String>)credentialsProvider;
    }
    @SuppressWarnings("unchecked")
    public static Object get_credentialsProviderName(Object __instance) {
        return ((DataSourceRuntimeConfig)__instance).credentialsProviderName;
    }
    @SuppressWarnings("unchecked")
    public static void set_credentialsProviderName(Object __instance, Object credentialsProviderName) {
        ((DataSourceRuntimeConfig)__instance).credentialsProviderName = (java.util.Optional<String>)credentialsProviderName;
    }
    public static Object construct() {
        return new DataSourceRuntimeConfig();
    }
}
